﻿// Registry Class v1.4
//
// released under MIT License (X11)
// http://www.opensource.org/licenses/mit-license.php
//
// Author: Niko Helle
// http://www.nikohelle.net

/*
Copyright (c) 2008 Niko Helle

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/



package com.nhe.utils
{
	
	/**
	 * The Registry is a singleton class for storing data that is accessed globally.
	 * Data can be any kind of object
	 * Store data: <code>Registry.add(NAME,VALUE);</code>
	 * Get data: <code>Registry.get(NAME,VALUE);</code>
	 */

	
    public class Registry
    {
        private static var _instance : Registry
		private var _data: Array
		
        public static function getInstance() : Registry
        {
            if ( _instance == null )
                _instance = new Registry( arguments.callee );
            return _instance;
        }
	   
        //NOTE: AS3 does not allow for private or protected constructors
        public function Registry( caller : Function = null ) : void
        {	
			_data = [];
            if( caller != Registry.getInstance )
                throw new Error ("Registry is a singleton class, use getInstance() instead");
			
            if ( Registry._instance != null )
                throw new Error( "Only one Registry instance should be instantiated" );	
				
            //put instantiation code here
        }
		
		/**
		 * Add data to the Registry
		 * <code>Registry.getInstance().addData(NAME,VALUE)
		 * <p>or <code>Registry.add(NAME,VALUE);</code></p>
		 *
		 * 
		 * @param name An unique identifier for the data
		 * @param data The data to store 
		 * 
		 * @return nothing
		 *
		 * @see Registry.add
		 */

		
		public function addData( name:String,data:*) :void
        {	
			_data[name] = data;
		}
		
		/**
		 * Get data from the Registry
		 * <code>Registry.getInstance().getData(NAME)
		 * <p>or <code>Registry.get(NAME);</code></p>
		 *
		 * 
		 * @param name The unique identifier of the data
		 * 
		 * @return The data
		 *
		 * @see Registry.get
		 */
		
		public function getData( name:String):*
        {	
			return _data[name];
		}
		
		/**
		 * Add data to the Registry
		 * <code>Registry.add(NAME,VALUE);</code>
		 *
		 * @param name An unique identifier for the data
		 * @param data The data to store 
		 * 
		 * @return nothing
		 *
		 * @see Registry.addData
		 */
		
		public static function add( name:String,data:*) :void
		{	
			Registry.getInstance().addData(name,data);
		}
		
		/**
		 * Get data from the Registry
		 * <code>Registry.get(NAME);</code>
		 *
		 * 
		 * @param name The unique identifier of the data
		 * 
		 * @return The data
		 *
		 * @see Registry.getData
		 */
		
		public static function get( name:String):*
		{	
			return Registry.getInstance().getData(name);
		}
		
    }
}
